@@ -12,8 +12,8 @@ from .quant_base import QuantBase
 
 
 class QuantLinear(QuantBase):
-    def __init__(self, name, module, bit_width, logger, writer):
-        super().__init__(name, module, bit_width, logger, writer)
+    def __init__(self, name, module, bit_width, writer):
+        super().__init__(name, module, bit_width, writer)
         self.activation_positive = False
 
 
