@@ -131,10 +131,11 @@ class QNQ():
                                          ", metrics: " + str(metrics_test))
                     else:
                         metrics_test = -1
+                        metrics.append(metrics_test)
                         # info log
                         self.logger.info("      weight_fl: " + str(test_fl) +
                                          ", metrics: " + str(metrics_test) +
-                                         ", below metrics_light_threshold ")
+                                         ", metrics_light failed.")
 
             # if need end search
             if end_search(metrics):
@@ -251,8 +252,8 @@ class QNQ():
             self.logger.info("Searching params...")
             #? only search when metrics drop 2 * self.threshold
             if metrics_origin - metrics_mid >= 2 * self.search_params_threshold:
-                self.logger.info("  Need to search, starting...")
-                # recover un-trim before search
+                self.logger.info("  Need to search params, starting...")
+                #! recover un-trim before search
                 for layer in self.quant_layer_list:
                     layer.recover_params()
                 # search params
@@ -278,7 +279,7 @@ class QNQ():
                                 str(layer.weight_fl) + ", metrics=" +
                                 str(metrics_mid))
             else:
-                metrics_mid = metrics_params
+                # metrics_mid = metrics_params
                 self.logger.info("    No need to search params, metrics=" +
                                  str(metrics_params))
             return metrics_mid
@@ -326,8 +327,8 @@ class QNQ():
                         layer.trim_activation()
                         metrics_tmp = self.metrics()
                         #? only search when metrics drop >= self.threshold
-                        if abs(metrics_tmp -
-                               metrics_mid) >= self.search_activation_threshold:
+                        if abs(metrics_tmp - metrics_mid
+                               ) >= self.search_activation_threshold:
                             self.logger.info(
                                 "    Need to search, activation_fl=" +
                                 str(layer.activation_fl) + ", metrics=" +
@@ -388,8 +389,10 @@ class QNQ():
         self.logger.info("  Search_activation: " + str(self.search_activation))
         self.logger.info("  Search_group: " + str(self.search_group))
         self.logger.info("  Group_num: " + str(self.group_num))
-        self.logger.info("  Search_params_threshold: " + str(self.search_params_threshold))
-        self.logger.info("  Search_activation_threshold: " + str(self.search_activation_threshold))
+        self.logger.info("  Search_params_threshold: " +
+                         str(self.search_params_threshold))
+        self.logger.info("  Search_activation_threshold: " +
+                         str(self.search_activation_threshold))
         self.logger.info("  Metrics_light: " +
                          str(bool(self.metrics_light_threshold)))
         self.logger.info("  Metrics_light_threshold: " +
@@ -470,8 +473,10 @@ class QNQ():
         qparams['qconfig']['quantize_activation'] = self.quantize_activation
         qparams['qconfig']['search_activation'] = self.search_activation
         qparams['qconfig']['search_group'] = self.search_group
-        qparams['qconfig']['search_params_threshold'] = self.search_params_threshold
-        qparams['qconfig']['search_activation_threshold'] = self.search_activation_threshold
+        qparams['qconfig'][
+            'search_params_threshold'] = self.search_params_threshold
+        qparams['qconfig'][
+            'search_activation_threshold'] = self.search_activation_threshold
         qparams['qconfig'][
             'metrics_light_threshold'] = self.metrics_light_threshold
         qparams['qconfig']['notes'] = "Value '-1' means no operation."
@@ -511,8 +516,10 @@ class QNQ():
             'quantize_activation']
         self.search_activation = self.qparams['qconfig']['search_activation']
         self.search_group = self.qparams['qconfig']['search_group']
-        self.search_params_threshold = self.qparams['qconfig']['search_params_threshold']
-        self.search_activation_threshold = self.qparams['qconfig']['search_activation_threshold']
+        self.search_params_threshold = self.qparams['qconfig'][
+            'search_params_threshold']
+        self.search_activation_threshold = self.qparams['qconfig'][
+            'search_activation_threshold']
         self.metrics_light_threshold = self.qparams['qconfig'][
             'metrics_light_threshold']
 
