@@ -1,23 +1,23 @@
-import json
+import yaml
 # This script contain func help generating a onnx-caffe index.
 # Author:
 #     Albert Dongz
 # History:
 #     2020.10.15 First Release
 # Dependencies:
-#     json
+#     yaml
 # Attention:
 #     1. Nothing
 
 
-def gen_index(json_file, onnx_model):
+def gen_index(yaml_file, onnx_model):
     """generate a onnx-caffe index
 
     Args:
-        json_file (str): json file you want to save
+        yaml_file (str): yaml file you want to save
         onnx_model (onnx_model): model load from onnx file
     """
-    with open(json_file, 'w+') as f:
+    with open(yaml_file, 'w+') as f:
         index = list(
             map(
                 lambda x: {
@@ -25,4 +25,4 @@ def gen_index(json_file, onnx_model):
                     'layer_num': int(list(x.output)[0]),
                     'param': list(x.input)
                 }, list(onnx_model.graph.node)))
-        json.dump(index, f)
+        yaml.dump(index, f)
