@@ -11,33 +11,86 @@
 import os
 import torch
 import logging
+import logging.config
 import datetime
-import json
 import torch.nn as nn
+import yaml
+from yaml.loader import SafeLoader
 
 
-def lognow(path="./checkpoints/"):
+# https://www.cnblogs.com/qianyuliang/p/7234217.html
+# https://stackoverflow.com/questions/17108973/python-logging-display-only-information-from-debug-level
+# todo
+# https://docs.python.org/zh-cn/3/library/logging.config.html#access-to-external-objects
+def setup_logging(save_path="./checkpoints",
+                  config_path=None,
+                  env_key="LOG_CFG"):
+    # get current time and create log dir
+    now = datetime.datetime.now().strftime('%Y-%m-%d--%H-%M-%S')
+    log_path = os.path.normpath(save_path + '/' + now)
+    if not os.path.exists(log_path):
+        os.makedirs(log_path)
+
+    # external config path
+    if config_path is None:
+        # get this file real abstract path
+        module_path = os.path.dirname(os.path.realpath(__file__))
+        # get default yaml file path
+        config_path = os.path.join(module_path, "logging.yaml")
+    path = config_path
+    value = os.getenv(env_key, None)
+    if value:
+        path = value
+
+    # load configuration
+    if os.path.exists(path):
+        with open(path, "r") as f:
+            config = yaml.load(f, Loader=SafeLoader)
+            # add log_path prefix
+            # todo, make here more beauty
+            config['handlers']['info_file_handler'][
+                'filename'] = os.path.normpath(
+                    log_path + '/' +
+                    config['handlers']['info_file_handler']['filename'])
+            config['handlers']['debug_file_handler'][
+                'filename'] = os.path.normpath(
+                    log_path + '/' +
+                    config['handlers']['debug_file_handler']['filename'])
+            config['handlers']['error_file_handler'][
+                'filename'] = os.path.normpath(
+                    log_path + '/' +
+                    config['handlers']['error_file_handler']['filename'])
+            logging.config.dictConfig(config)
+
+    else:
+        lognow(save_path)
+
+    return log_path
+
+
+# deprecated
+def lognow(save_path="./checkpoints/"):
     """This function set up logging.
 
     Keyword Arguments:
-        path {str} -- log save path (default: {"./checkpoints/"})
+        save_path {str} -- log save path (default: {"./checkpoints/"})
 
     Returns:
         str -- log absolute path, contain time and param path.
     """
     # get current time and create log dir
     now = datetime.datetime.now().strftime('%Y-%m-%d--%H-%M-%S')
-    log_path = os.path.normpath(path + '/' + now)
+    log_path = os.path.normpath(save_path + '/' + now)
     if not os.path.exists(log_path):
         os.makedirs(log_path)
 
     # setting up logging
-    logger = logging.getLogger(__name__)
+    logger = logging.getLogger("qnq")
     logger.setLevel(level=logging.DEBUG)
     handler = logging.FileHandler(log_path + "/qnq.log")
     handler.setLevel(logging.DEBUG)
-    formatter = logging.Formatter(
-        "%(asctime)s - %(levelname)s - %(message)s", "%H:%M:%S")
+    formatter = logging.Formatter("%(asctime)s - %(levelname)s - %(message)s",
+                                  "%H:%M:%S")
     handler.setFormatter(formatter)
     console = logging.StreamHandler()
     console.setLevel(logging.INFO)
